#ifndef __MOG2_EDITOR
#define __MOG2_EDITOR

#define GAME_VIEW		0
#define MAP_VIEW		1
#define ROOM_VIEW		2
#define OBJECT_VIEW		3
#define GRABBER_VIEW	4
#define INTERFACE_VIEW	5


class EDITOR {

	friend class GVariableWnd;
	friend class AVariableWnd;
	friend class GMapWnd;
	friend class GTopWnd;
	friend class MTopWnd;
	friend class MVariableWnd;
	friend class MRoomsWnd;
	friend class MMapWnd;
	friend class RObjectWnd;
	friend class RTopWnd;
	friend class RVariableWnd;
	friend class REditWnd;
	friend class RToolsWnd;
	friend class OTopWnd;
	friend class OBitmapWnd;
	friend class OSampleWnd;
	friend class OObjectWnd;
	friend class OObjectBmpWnd;
	friend class OPropertiesWnd;
	friend class GrabTopWnd;
	friend class GrabGrabberWnd;
	friend class GrabToolsWnd;
	friend class BActionEditorWnd;
	friend class OVariableWnd;
	friend class BOVariableEditorWnd;
	friend class VariableListWnd;
	friend class SampleSelectorDlg;
	friend class ITopWnd;
	friend class IObjectWnd;
	friend class IVariableWnd;
	friend class IToolsWnd;
	friend class IEditWnd;

	friend class BViewAnimScriptWnd;
	friend class BViewActionScriptWnd;
	friend class BViewConditionScriptWnd;
	friend class BViewValueScriptWnd;

public:
	EDITOR(TTF_Font *font);
	~EDITOR();

	bool cycle(void);
	bool event(SDL_Event *event);
	void redraw(SDL_Surface *sfc);

	void set_all_dirty(void);

private:

	void delete_tile(class TILE *t);
	void delete_object(class OBJECT *o);

	int view;
	class MOG2 *game;
	class MAP *map;
	class ROOM *room;
	TTF_Font *font;

	bool show_miniatures;

	/* GAME_VIEW: */ 
	int gv_separator_x;
	int gv_separator_y;
	GVariableWnd *GVW;
	AVariableWnd *AVW;
	GMapWnd *GMW;
	GTopWnd *GTW;

	/* MAP_VIEW: */ 
	int mv_separator_x;
	int mv_separator_y;
	ROOM *mv_selected;
	MTopWnd *MTW;
	MVariableWnd *MVW;
	MRoomsWnd *MRW;
	MMapWnd *MMW;

	/* ROOM_VIEW: */ 
	int rv_separator_x;
	int rv_separator1_y;
	int rv_separator2_y;
	OBJECT *rv_selected_obj;
	TILE *rv_selected_tile;
	bool rv_displaying_objects;
	int rv_editing;
	int rv_editmode;
	int rv_grid;
	PLACED_OBJECT *rv_dragging_object;
	ROOM rv_cliproom;
	RTopWnd *RTW;
	RVariableWnd *RVW;
	RObjectWnd *ROW;
	REditWnd *REW;
	RToolsWnd *RToolW;

	/* OBJECT_VIEW: */ 
	int ov_separator1_x;
	int ov_separator2_x;
	int ov_separator_y;
	int ov_last_view;
	OBJECT *ov_selected;
	int ov_selected_ob;
	int ov_bitmap_category;
	TILE *ov_regrabbing;
	BButton *ov_bitmaps_button;
	BButton *ov_samples_button;
	bool ov_showing_bitmaps;
	OTopWnd *OTW;
	OBitmapWnd *OBW;
	OSampleWnd *OSW;
	OObjectWnd *OOW;
	OObjectBmpWnd *OOBW;
	OPropertiesWnd *OPW;

	/* GRABBER VIEW: */ 
	GrabTopWnd *GrabTW;
	GrabGrabberWnd *GrabGW;
	GrabToolsWnd *GrabToolW;
	SDL_Surface *grabv_bitmap;
	int grabv_grid;
	int grabv_grid_x,grabv_grid_y;
	int grabv_state;
	char grabv_bitmap_file[256];

	/* INTERFACE VIEW: */ 
	int iv_separator_x;
	int iv_separator1_y;
	int iv_separator2_y;
	MOG2_INTERFACE *interf;
	OBJECT *iv_selected_obj;
	TILE *iv_selected_tile;
	bool iv_displaying_objects;
	int iv_grid;
	int iv_editing;
	int iv_editmode;
	PLACED_OBJECT *iv_dragging_object;
	MOG2_INTERFACE iv_clipinterf;
	ITopWnd *ITW;
	IObjectWnd *IOW;
	IVariableWnd *IVW;
	IEditWnd *IEW;
	IToolsWnd *IToolW;

	/* SCRIPT EDITORS */ 
	int se_clipboard_content;	/* 0 - Nothing		*/ 
								/* 1 - Animation	*/ 
								/* 2 - Action		*/ 
								/* 3 - Condition	*/ 
								/* 4 - Value		*/ 
	class AnimSCRIPT *se_clipboard_anim;
	class ActionSCRIPT *se_clipboard_action;
	class ConditionSCRIPT *se_clipboard_condition;
	class ValueSCRIPT *se_clipboard_value;
};

#endif

